websweep package
================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   websweep.consolidator
   websweep.crawler
   websweep.extractor
   websweep.utils

Submodules
----------

websweep.config module
----------------------

.. automodule:: websweep.config
   :members:
   :show-inheritance:
   :undoc-members:

websweep.main module
--------------------

.. automodule:: websweep.main
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: websweep
   :members:
   :show-inheritance:
   :undoc-members:
